@@ -56,7 +56,7 @@ class Device_Base(Item_Base):
                 #self.get_status()
             elif event.action == "CE": # comms error clear
                 self.set_property ('status','ready')
-                print('comms error cleareed!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
+                #print('comms error cleareed!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!')
 
     def get_status(self): #isy status for node
         path = "status/" + self.address 
@@ -85,6 +85,7 @@ class Device_Base(Item_Base):
         if self.last_command_path is not None:
             if (datetime.now()-self.last_command_time).seconds <= self.last_command_retry_interval:
                 def send_request():
+                    self.send_request(self.last_command_path) # do it twice!
                     self.send_request(self.last_command_path)
 
                 # **** not sure this is a good way to do this but cannot call send request in the websocket call back
