@@ -11,7 +11,5 @@ class Device_Dimmer(Device_Base):
         self.add_property("level", 0)  # in percent
 
     def set_level(self, level):
-        #self.set_property("level",level) # set in websocket return event
+        pass
 
-        if self.get_property("status")=="alert":
-            print ("DEVICE IN ALERT STATE")
