@@ -4,7 +4,7 @@ import asyncio
 import functools
 import logging
 import xml.etree.ElementTree as ET
-
+import traceback
 import aiohttp
 
 from .websocket_event import Websocket_Event
@@ -118,7 +118,7 @@ class Async_Session(object):
                 await asyncio.sleep(.5)
 
             except Exception as ex:
-                logger.warning("HTTP Get Error {} for path".format(ex,path))
+                logger.warning("Async HTTP Get Error {} for path {}".format(ex,path))
                 self.http_connected = False
                 await asyncio.sleep(.5)
 
@@ -132,10 +132,11 @@ class Async_Session(object):
             future = asyncio.run_coroutine_threadsafe(
                 self.request_async(path, timeout), self.loop
             )
-            return future.result(1)
+            return future.result(5)
 
         except Exception as ex:
-            logger.error("HTTP Get Error {} for path".format(ex,path))
+            logger.error("Request HTTP Get Error {} for path {}".format(ex,path))
+            traceback.print_exc()
             return False, None
 
     def start_websocket(self):
